package com.bweb.controller;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.hfkj.common.exception.ErrorCode;
import com.hfkj.common.exception.ErrorHelp;
import com.hfkj.common.exception.SysCode;
import com.hfkj.common.utils.*;
import com.hfkj.config.CommonSysConst;

import com.hfkj.entity.BsOrderGoods;
import com.hfkj.entity.GoodsLogistics;
import com.hfkj.entity.GoodsUserAddress;
import com.hfkj.meituan.MeiTuanService;
import com.hfkj.model.ResponseData;

import com.hfkj.service.goods.BsOrderGoodsService;
import com.hfkj.service.goods.GoodsUserAddressService;
import com.hfkj.sysenum.order.OrderLogisticsStatusEnum;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.*;
import java.util.stream.Collectors;


@Controller
@RequestMapping(value="/test")
@Api(value="测试")
public class TestController {
    private static Logger log = LoggerFactory.getLogger(TestController.class);
    @Resource
    private BsOrderGoodsService orderGoodsService;
    @Resource
    private GoodsUserAddressService addressService;
    @Resource
    private BsOrderGoodsService bsOrderGoodsService;

    @RequestMapping(value="/haiOilLogin",method = RequestMethod.POST)
    @ResponseBody
    @ApiOperation(value = "嗨加油登陆参数")
    public ResponseData haiOilLogin(@RequestBody JSONObject body) {
        try {

            if (body == null|| StringUtils.isBlank(body.getString("phone"))) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.REQ_PARAMS_ERROR, "");
            }

            Map<String , Object> map = new HashMap<>();
            map.put("appid" , CommonSysConst.getSysConfig().getHaiOilAppid());
            map.put("phone" , body.getString("phone"));
            map.put("sign" , SignatureUtil.createSign(map , CommonSysConst.getSysConfig().getHaiOilAppSecret()));


            return ResponseMsgUtil.success(map);

        } catch (Exception e) {
            log.error("error!",e);
            return ResponseMsgUtil.exception(e);
        }
    }

    @RequestMapping(value="/getLogisticsMsg",method = RequestMethod.POST)
    @ResponseBody
    @ApiOperation(value = "物流查询")
    public ResponseData getLogisticsMsg() {
        try {

            Map<String , Object> objectMap = new HashMap<>();

            objectMap.put("status" , 2);
            objectMap.put("createTime" , "createTime");

            List<BsOrderGoods> orderGoodsList = orderGoodsService.getList(objectMap);

            orderGoodsList = orderGoodsList.stream().filter(order -> order.getLogisticsNo() != null).collect(Collectors.toList());

            for (BsOrderGoods goods : orderGoodsList) {

                if (goods.getLogisticsNo() != null) {
                    GoodsLogistics logistics = (GoodsLogistics) bsOrderGoodsService.getLogisticsMsgSchedule(goods.getLogisticsNo() , goods.getUserPhone());
                    if (logistics.getLogisticsStatus() != null) {
                        goods.setLogisticsStatus(logistics.getLogisticsStatus());
                        goods.setLogisticsStatusDesc(logistics.getLogisticsStatusDesc());

                    } else {
                        goods.setLogisticsStatus(OrderLogisticsStatusEnum.statusWAIT_ACCEPT.getCode());
                        goods.setLogisticsStatusDesc(OrderLogisticsStatusEnum.statusWAIT_ACCEPT.getName());
                    }

                    goods.setUpdateTime(new Date());

                    bsOrderGoodsService.update(goods);
                }

            }
            return ResponseMsgUtil.success("map");

        } catch (Exception e) {
            log.error("error!",e);
            return ResponseMsgUtil.exception(e);
        }
    }

    @RequestMapping(value="/orderGoodsConfirmReceipt",method = RequestMethod.POST)
    @ResponseBody
    @ApiOperation(value = "状态更新")
    public void orderGoodsConfirmReceipt() {
        Map<String , Object> map = new HashMap<>();

        map.put("logisticsStatus" , "SIGN");
        map.put("status" , 2);

        List<BsOrderGoods> orderGoodsList = orderGoodsService.getList(map);

        for (BsOrderGoods goods : orderGoodsList) {

            // 判断时间是否是十天前

            if (DateUtil.differentDays(goods.getCreateTime() , new Date()) > 10) {
                orderGoodsService.confirmReceipt(goods.getId());
            }
        }
    }


    @RequestMapping(value = "/loginFree", method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "H5免登接口")
    public ResponseData loginFree(@RequestParam(name = "staffPhone", required = true) String staffPhone,
                                  @RequestParam(name = "productType", required = true) String productType) {
        try {

            Map<String , Object> map = new HashMap<>();
            Map<String , Object> staffInfo = new HashMap<>();

            staffInfo.put("staffPhone", staffPhone);

            map.put("staffInfo", staffInfo);
            map.put("entId", 104310L);
            map.put("ts", new Date().getTime());
            map.put("productType", productType);
            map.put("nonce" , RandomStringGeneratorUtil.generateRandomString(36));
            JSONObject jsonObject = MeiTuanService.loginFree(map);
            JSONArray jsonArray = jsonObject.getJSONArray("url");
            JSONObject json = jsonArray.getJSONObject(0);
            return ResponseMsgUtil.success(json.getString("value"));

        } catch (Exception e) {
            log.error("HighUserCardController --> getHuiLianTongCardConsume() error!", e);
            return ResponseMsgUtil.exception(e);
        }
    }

}
